@@ -1,7 +1,7 @@
 '''HyperEstraier
 Hiroki Ohtani
 "HyperEstraier Pure Python Implementation."
-http://www.liris.org/program/hyperestraier/
+http://www.liris.org/trac/wiki/PyHyperEstraier
 '''
 
 
@@ -12,7 +12,7 @@ import urllib
 import urllib2
 import re
 
-__version__  = '0.10.4'
+__version__  = '0.10.5'
 __author__ = "Hiroki Ohtani (liris.pp@gmail.com)"
 __contributors__ = ["Junji NAKANISHI <daemonfreaks@gmail.com>"]
 __copyright__ = "Copyright (c) 2006 Hiroki Ohtani"
@@ -883,10 +883,15 @@ class Node(object):
                             elems = rdline.split("=", 1)
                             if len(elems)==2:
                                 rdattrs[elems[0]] = elems[1]
+
+                    inSnippet = False
                     while len(lines):
                         rdline = lines.pop(0)
                         if not rdline:
-                            break
+                            if not inSnippet:
+                                inSnippet = True
+                            else:
+                                break
                         sb.append(rdline)
                     rduri = rdattrs.setdefault("@uri", None)
                     rdsnippet = "\n".join(sb)
